package de.intevation.flys.client.server;

import org.w3c.dom.Document;

import org.apache.log4j.Logger;

import de.intevation.artifacts.common.utils.ClientProtocolUtils;

import de.intevation.artifacts.httpclient.exceptions.ConnectionException;
import de.intevation.artifacts.httpclient.http.HttpClient;
import de.intevation.artifacts.httpclient.http.HttpClientImpl;
import de.intevation.artifacts.httpclient.http.response.DocumentResponseHandler;

import de.intevation.flys.client.shared.exceptions.ServerException;
import de.intevation.flys.client.shared.model.Collection;

import de.intevation.flys.client.client.services.CollectionAttributeService;


/**
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class CollectionAttributeServiceImpl
extends      DescribeCollectionServiceImpl
implements   CollectionAttributeService
{
    private static final Logger logger =
        Logger.getLogger(CollectionAttributeServiceImpl.class);


    public static final String ERROR_UPDATING_COLLECTION_ATTRIBUTE =
        "error_update_collection_attribute";


    public Collection update(Collection collection, String url, String locale)
    throws ServerException
    {
        logger.info("CollectionAttributeServiceImpl.update");

        Document attribute = CollectionHelper.createAttribute(collection);
        Document action    = ClientProtocolUtils.newSetAttributeDocument(
            collection.identifier(),
            attribute);

        try {
            HttpClient http = new HttpClientImpl(url, locale);
            Document   res  = (Document) http.doCollectionAction(
                action,
                collection.identifier(),
                new DocumentResponseHandler());

            logger.debug("Collection attribute successfully set.");

            return describe(collection.identifier(), url, locale);
        }
        catch (ConnectionException ce) {
            logger.error(ce, ce);
        }

        throw new ServerException(ERROR_UPDATING_COLLECTION_ATTRIBUTE);
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
